@@ -25,7 +25,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 #include <string.h>
 #include <stdlib.h>
 #include <glib/gprintf.h>
@@ -143,106 +143,6 @@ gdk_property_get (GdkWindow   *window,
   return FALSE;
 }
 
-static gboolean
-find_common_locale (const guchar  *data,
-		    gint           nelements,
-		    gint           nchars,
-		    LCID          *lcidp,
-		    guchar       **bufp,
-		    gint          *sizep)
-{
-  static struct {
-    LCID lcid;
-    UINT cp;
-  } locales[] = {
-#define ENTRY(lang, sublang) \
- { MAKELCID (MAKELANGID (LANG_##lang, SUBLANG_##sublang), SORT_DEFAULT), 0 }
-    ENTRY (ENGLISH, DEFAULT),
-    ENTRY (POLISH, DEFAULT),
-    ENTRY (CZECH, DEFAULT),
-    ENTRY (LITHUANIAN, DEFAULT),
-    ENTRY (RUSSIAN, DEFAULT),
-    ENTRY (GREEK, DEFAULT),
-    ENTRY (TURKISH, DEFAULT),
-    ENTRY (HEBREW, DEFAULT),
-    ENTRY (ARABIC, DEFAULT),
-    ENTRY (THAI, DEFAULT),
-    ENTRY (JAPANESE, DEFAULT),
-    ENTRY (CHINESE, CHINESE_SIMPLIFIED),
-    ENTRY (CHINESE, CHINESE_TRADITIONAL),
-    ENTRY (KOREAN, DEFAULT),
-#undef ENTRY
-  };
-
-  static gboolean been_here = FALSE;
-  gint i;
-  wchar_t *wcs;
-
-  /* For each installed locale: Get the locale's default code page,
-   * and store the list of locales and code pages.
-   */
-  if (!been_here)
-    {
-      been_here = TRUE;
-      for (i = 0; i < G_N_ELEMENTS (locales); i++)
-	if (IsValidLocale (locales[i].lcid, LCID_INSTALLED))
-	  {
-	    gchar buf[10];
-	    if (GetLocaleInfo (locales[i].lcid, LOCALE_IDEFAULTANSICODEPAGE,
-			       buf, sizeof (buf)))
-	      {
-		gchar name[100];
-		locales[i].cp = atoi (buf);
-		GDK_NOTE (DND, (GetLocaleInfo (locales[i].lcid,
-					       LOCALE_SENGLANGUAGE,
-					       name, sizeof (name)),
-				g_print ("locale %#lx: %s: CP%d\n",
-					 (gulong) locales[i].lcid, name,
-					 locales[i].cp)));
-	      }
-	  }
-    }
-  
-  /* Allocate bufp big enough to store data in any code page.  Two
-   * bytes for each Unicode char should be enough, Windows code pages
-   * are either single- or double-byte.
-   */
-  *bufp = g_malloc ((nchars+1)*2);
-
-  /* Convert to Windows wide chars into temp buf */
-  wcs = g_utf8_to_utf16 (data, nelements, NULL, NULL, NULL);
-
-  /* For each code page that is the default for an installed locale: */
-  for (i = 0; i < G_N_ELEMENTS (locales); i++)
-    {
-      BOOL used_default;
-      int nbytes;
-
-      if (locales[i].cp == 0)
-	continue;
-
-      /* Convert to that code page into bufp */
-      
-      nbytes = WideCharToMultiByte (locales[i].cp, 0, wcs, -1,
-				    *bufp, (nchars+1)*2,
-				    NULL, &used_default);
-
-      if (!used_default)
-	{
-	  /* This locale is good for the string */
-	  g_free (wcs);
-	  *lcidp = locales[i].lcid;
-	  *sizep = nbytes;
-	  return TRUE;
-	}
-    }
-
-  g_free (*bufp);
-  g_free (wcs);
-
-  return FALSE;
-}
-
 void
 gdk_property_change (GdkWindow    *window,
 		     GdkAtom       property,
@@ -252,17 +152,14 @@ gdk_property_change (GdkWindow    *window,
 		     const guchar *data,
 		     gint          nelements)
 {
-  HGLOBAL hdata, hlcid, hutf8;
+  HGLOBAL hdata;
   UINT cf = 0;
-  LCID lcid;
-  LCID *lcidptr;
-  GString *rtf = NULL;
   gint i, size, nchars;
   gchar *prop_name, *type_name;
   guchar *ucptr, *buf = NULL;
   wchar_t *wcptr;
   glong wclen;
-  enum { SYSTEM_CODEPAGE, UNICODE_TEXT, SINGLE_LOCALE, RICH_TEXT } method;
+  enum { SYSTEM_CODEPAGE, UNICODE_TEXT } method;
   gboolean ok = TRUE;
 
   g_return_if_fail (window != NULL);
@@ -274,10 +171,10 @@ gdk_property_change (GdkWindow    *window,
   GDK_NOTE (DND,
 	    (prop_name = gdk_atom_name (property),
 	     type_name = gdk_atom_name (type),
-	     g_print ("gdk_property_change: %p %#x (%s) %#x (%s) %s %d*%d bytes: %s\n",
+	     g_print ("gdk_property_change: %p %p (%s) %p (%s) %s %d*%d bytes: %s\n",
 		      GDK_WINDOW_HWND (window),
-		      (guint) property, prop_name,
-		      (guint) type, type_name,
+		      property, prop_name,
+		      type, type_name,
 		      (mode == GDK_PROP_MODE_REPLACE ? "REPLACE" :
 		       (mode == GDK_PROP_MODE_PREPEND ? "PREPEND" :
 			(mode == GDK_PROP_MODE_APPEND ? "APPEND" :
@@ -305,7 +202,7 @@ gdk_property_change (GdkWindow    *window,
 	      return;
 	    }
 
-	  nchars = g_utf8_strlen (data, nelements);
+	  nchars = g_utf8_strlen ((char*) data, nelements);
 
 	  /* Check if only ASCII */
 	  for (i = 0; i < nelements; i++)
@@ -314,9 +211,7 @@ gdk_property_change (GdkWindow    *window,
 
 	  if (i == nelements)
 	    {
-	      /* If UTF-8 and only ASCII, use CF_TEXT and the data as
-	       * such.
-	       */
+	      /* If only ASCII, use CF_TEXT and the data as such */
 	      method = SYSTEM_CODEPAGE;
 	      size = nelements;
 	      for (i = 0; i < nelements; i++)
@@ -325,14 +220,12 @@ gdk_property_change (GdkWindow    *window,
 	      size++;
 	      GDK_NOTE (DND, g_print ("... as text: %.40s\n", data));
 	    }
-	  else if (G_WIN32_IS_NT_BASED ())
+	  else
 	    {
-	      /* On NT, use CF_UNICODETEXT if any non-system codepage
-	       * char present.
-	       */
+	      /* Use CF_UNICODETEXT */
 	      method = UNICODE_TEXT;
 
-	      wcptr = g_utf8_to_utf16 (data, nelements, NULL, &wclen, NULL);
+	      wcptr = g_utf8_to_utf16 ((char *) data, nelements, NULL, &wclen, NULL);
 
 	      wclen++;		/* Terminating 0 */
 	      size = wclen * 2;
@@ -341,76 +234,13 @@ gdk_property_change (GdkWindow    *window,
 		  size += 2;
 	      GDK_NOTE (DND, g_print ("... as Unicode\n"));
 	    }
-	  else if (find_common_locale (data, nelements, nchars, &lcid, &buf, &size))
-	    {
-	      /* On Win9x, if all chars are in the default code page
-	       * of some installed locale, use CF_TEXT and CF_LOCALE.
-	       */
-	      method = SINGLE_LOCALE;
-	      GDK_NOTE (DND, g_print ("... as text in locale %#lx %d bytes\n",
-				      (gulong) lcid, size));
-	    }
-	  else
-	    {
-	      /* On Win9x, otherwise use RTF */
-
-	      const guchar *p = data;
-
-	      /* WordPad on XP, at least, doesn't seem to grok \uc0
-	       * -encoded Unicode characters. Oh well, use \uc1 then,
-	       * with a question mark as the "ANSI" stand-in for each
-	       * non-ASCII Unicode character. (WordPad for XP? This
-	       * code path is for Win9x! Yes, but I don't have Win9x,
-	       * so I use XP to test, using the G_WIN32_PRETEND_WIN9X
-	       * environment variable.)
-	       */
-	      method = RICH_TEXT;
-	      rtf = g_string_new ("{\\rtf1\\uc1 ");
-
-	      while (p < data + nelements)
-		{
-		  if (*p == '{' ||
-		      *p == '\\' ||
-		      *p == '}')
-		    {
-		      rtf = g_string_append_c (rtf, '\\');
-		      rtf = g_string_append_c (rtf, *p);
-		      p++;
-		    }
-		  else if (*p < 0200 && *p >= ' ')
-		    {
-		      rtf = g_string_append_c (rtf, *p);
-		      p++;
-		    }
-		  else
-		    {
-		      guchar *q;
-		      gint n;
-		      
-		      rtf = g_string_append (rtf, "\\uNNNNN ?");
-		      rtf->len -= 7; /* five digits a space and a question mark */
-		      q = rtf->str + rtf->len;
-		      n = g_sprintf (q, "%d ?", g_utf8_get_char (p));
-		      g_assert (n <= 7);
-		      rtf->len += n;
-		      
-		      p = g_utf8_next_char (p);
-		    }
-		}
-	      rtf = g_string_append (rtf, "}");
-	      size = rtf->len + 1;
-	      GDK_NOTE (DND, g_print ("... as RTF: %.40s\n", rtf->str));
-	    }
 	  
 	  if (!(hdata = GlobalAlloc (GMEM_MOVEABLE, size)))
 	    {
 	      WIN32_API_FAILED ("GlobalAlloc");
 	      if (!CloseClipboard ())
 		WIN32_API_FAILED ("CloseClipboard");
-	      if (buf != NULL)
-		g_free (buf);
-	      if (rtf != NULL)
-		g_string_free (rtf, TRUE);
+	      g_free (buf);
 	      return;
 	    }
 
@@ -443,48 +273,6 @@ gdk_property_change (GdkWindow    *window,
 	      }
 	      break;
 
-	    case SINGLE_LOCALE:
-	      cf = CF_TEXT;
-	      memmove (ucptr, buf, size);
-	      g_free (buf);
-
-	      /* Set the CF_LOCALE clipboard data, too */
-	      if (!(hlcid = GlobalAlloc (GMEM_MOVEABLE, sizeof (LCID))))
-		WIN32_API_FAILED ("GlobalAlloc"), ok = FALSE;
-	      if (ok)
-		{
-		  lcidptr = GlobalLock (hlcid);
-		  *lcidptr = lcid;
-		  GlobalUnlock (hlcid);
-		  GDK_NOTE (DND, g_print ("... SetClipboardData(CF_LOCALE,%p)\n",
-					  hlcid));
-		  if (!SetClipboardData (CF_LOCALE, hlcid))
-		    WIN32_API_FAILED ("SetClipboardData(CF_LOCALE)"), ok = FALSE;
-		}
-	      break;
-
-	    case RICH_TEXT:
-	      cf = _cf_rtf;
-	      memmove (ucptr, rtf->str, size);
-	      g_string_free (rtf, TRUE);
-
-	      /* Set the UTF8_STRING clipboard data, too, for other
-	       * GTK+ apps to use (won't bother reading RTF).
-	       */
-	      if (!(hutf8 = GlobalAlloc (GMEM_MOVEABLE, nelements)))
-		WIN32_API_FAILED ("GlobalAlloc");
-	      else
-		{
-		  guchar *utf8ptr = GlobalLock (hutf8);
-		  memmove (utf8ptr, data, nelements);
-		  GlobalUnlock (hutf8);
-		  GDK_NOTE (DND, g_print ("... SetClipboardData('UTF8_STRING',%p)\n",
-					  hutf8));
-		  if (!SetClipboardData (_cf_utf8_string, hutf8))
-		    WIN32_API_FAILED ("SetClipboardData('UTF8_STRING')");
-		}
-	      break;
-
 	    default:
 	      g_assert_not_reached ();
 	    }
@@ -532,9 +320,9 @@ gdk_property_delete (GdkWindow *window,
 
   GDK_NOTE (DND,
 	    (prop_name = gdk_atom_name (property),
-	     g_print ("gdk_property_delete: %p %#x (%s)\n",
+	     g_print ("gdk_property_delete: %p %p (%s)\n",
 		      GDK_WINDOW_HWND (window),
-		      (guint) property, prop_name),
+		      property, prop_name),
 	     g_free (prop_name)));
 
   if (property == _gdk_selection_property)
@@ -565,6 +353,7 @@ gdk_property_delete (GdkWindow *window,
   { "Gtk/ToolbarIconSize", "gtk-toolbar-icon-size" },
   { "Gtk/IMPreeditStyle", "gtk-im-preedit-style" },
   { "Gtk/IMStatusStyle", "gtk-im-status-style" },
+  { "Gtk/IMModule", "gtk-im-module" },
   { "Net/CursorBlink", "gtk-cursor-blink" },
   { "Net/CursorBlinkTime", "gtk-cursor-blink-time" },
   { "Net/ThemeName", "gtk-theme-name" },
@@ -632,6 +421,12 @@ gdk_screen_get_setting (GdkScreen   *screen,
       g_value_set_boolean (value, TRUE);
       return TRUE;
     }
+  else if (strcmp ("gtk-alternative-sort-arrows", name) == 0)
+    {
+      GDK_NOTE(MISC, g_print("gdk_screen_get_setting(\"%s\") : TRUE\n", name));
+      g_value_set_boolean (value, TRUE);
+      return TRUE;
+    }
 #if 0
   /*
    * With 'MS Sans Serif' as windows menu font (default on win98se) you'll get a 
