@@ -24,7 +24,6 @@
 #include "gtkcellrendereraccel.h"
 #include "gtklabel.h"
 #include "gtkeventbox.h"
-#include "gtkmain.h"
 #include "gtkprivate.h"
 #include "gdk/gdkkeysyms.h"
 #include "gtkalias.h"
@@ -53,10 +52,6 @@ static GtkCellEditable *
                                                   GdkRectangle    *background_area,
                                                   GdkRectangle    *cell_area,
                                                   GtkCellRendererState flags);
-static gchar *convert_keysym_state_to_string     (GtkCellRendererAccel *accel,
-                                                  guint                 keysym,
-                                                  GdkModifierType       mask,
-                                                  guint                 keycode);
 
 enum {
   ACCEL_EDITED,
@@ -79,11 +74,6 @@ G_DEFINE_TYPE (GtkCellRendererAccel, gtk_cell_renderer_accel, GTK_TYPE_CELL_REND
 static void
 gtk_cell_renderer_accel_init (GtkCellRendererAccel *cell_accel)
 {
-  gchar *text;
-
-  text = convert_keysym_state_to_string (cell_accel, 0, 0, 0);
-  g_object_set (cell_accel, "text", text, NULL);
-  g_free (text);
 }
 
 static void
@@ -239,30 +229,19 @@ convert_keysym_state_to_string (GtkCellRendererAccel *accel,
 {
   if (keysym == 0 && keycode == 0)
     /* This label is displayed in a treeview cell displaying
-     * a disabled accelerator key combination.
+     * a disabled accelerator key combination. Only include
+     * the text after the | in the translation.
      */
-    return g_strdup (C_("Accelerator", "Disabled"));
+    return g_strdup (Q_("Accelerator|Disabled"));
   else 
     {
       if (accel->accel_mode == GTK_CELL_RENDERER_ACCEL_MODE_GTK)
-        {
-          if (!gtk_accelerator_valid (keysym, mask))
-            /* This label is displayed in a treeview cell displaying
-             * an accelerator key combination that is not valid according
-             * to gtk_accelerator_valid().
-             */
-            return g_strdup (C_("Accelerator", "Invalid"));
-
-          return gtk_accelerator_get_label (keysym, mask);
-        }
+	return gtk_accelerator_get_label (keysym, mask);
       else 
 	{
 	  gchar *name;
 
-	  name = gtk_accelerator_get_label (keysym, mask);
-	  if (name == NULL)
-	    name = gtk_accelerator_name (keysym, mask);
-
+	  name = gtk_accelerator_name (keysym, mask);
 	  if (keysym == 0)
 	    {
 	      gchar *tmp;
@@ -471,7 +450,6 @@ grab_key_callback (GtkWidget            *widget,
   edited = TRUE;
 
  out:
-  gtk_grab_remove (accel->grab_widget);
   gdk_display_keyboard_ungrab (display, event->time);
   gdk_display_pointer_ungrab (display, event->time);
 
@@ -499,7 +477,6 @@ ungrab_stuff (GtkWidget            *widget,
 {
   GdkDisplay *display = gtk_widget_get_display (widget);
 
-  gtk_grab_remove (accel->grab_widget);
   gdk_display_keyboard_ungrab (display, GDK_CURRENT_TIME);
   gdk_display_pointer_ungrab (display, GDK_CURRENT_TIME);
 
@@ -609,8 +586,6 @@ gtk_cell_renderer_accel_start_editing (GtkCellRenderer      *cell,
   
   gtk_widget_show_all (accel->edit_widget);
 
-  gtk_grab_add (accel->grab_widget);
-
   g_signal_connect (G_OBJECT (accel->edit_widget), "unrealize",
                     G_CALLBACK (ungrab_stuff), accel);
   
