@@ -21,9 +21,13 @@
  * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
+#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_VSCROLLBAR_H__
 #define __GTK_VSCROLLBAR_H__
 
@@ -32,6 +36,9 @@
 #include <gtk/gtkscrollbar.h>
 
 
+G_BEGIN_DECLS
+
+
 #define GTK_TYPE_VSCROLLBAR            (gtk_vscrollbar_get_type ())
 #define GTK_VSCROLLBAR(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_VSCROLLBAR, GtkVScrollbar))
 #define GTK_VSCROLLBAR_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_VSCROLLBAR, GtkVScrollbarClass))
@@ -54,18 +61,11 @@ struct _GtkVScrollbarClass
 };
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
-
 GType      gtk_vscrollbar_get_type (void) G_GNUC_CONST;
 GtkWidget* gtk_vscrollbar_new      (GtkAdjustment *adjustment);
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 
 #endif /* __GTK_VSCROLLBAR_H__ */
